@@ -4,9 +4,9 @@ use 5.006;
 use strict;
 use warnings;
 
-use Rtmgr::Gen::Db qw(get_hash create_db_table get_name get_tracker calc_scene);
+use Rtmgr::Gen::Db qw(get_download_list create_db_table get_name get_tracker calc_scene insert_into_database_missing get_difference_between_server_and_database add_remove_extraneous_reccords);
 use Exporter 'import';
-our @EXPORT_OK = qw(get_hash create_db_table get_name get_tracker calc_scene);
+our @EXPORT_OK = qw(get_download_list create_db_table get_name get_tracker calc_scene insert_into_database_missing get_difference_between_server_and_database add_remove_extraneous_reccords);
 	
 =head1 NAME
 
@@ -14,11 +14,11 @@ Rtmgr::Gen - Connect to rTorrent/ruTorrent installation and get a list of torren
 
 =head1 VERSION
 
-Version 0.03
+Version 0.04
 
 =cut
 
-our $VERSION = '0.03';
+our $VERSION = '0.04';
 
 
 =head1 SYNOPSIS
